# This should be pushed to tainted as per Mageia's policy on emulators

%global __provides_exclude_from ^%{_libdir}/games/%{name}/.*\\.so$

# Comment out for stable release
#define git     1
%if 0%{?git}
%define date    20190505
%endif

%define rel     2

Name:           pcsx2
Version:        1.6.0
Release:        %mkrel %{?git:0.%{date}.}%{rel}
Summary:        Open source PlayStation 2 emulator
License:        GPLv2+
Group:          Emulators
Url:            https://pcsx2.net
%if 0%{?git}
# Snapshot from https://github.com/PCSX2/pcsx2
Source0:        %{name}-%{version}-%{date}.tar.xz
%else
Source0:        https://github.com/PCSX2/pcsx2/archive/v%{version}/%{name}-%{version}.tar.gz
%endif
Patch0:         pcsx2-1.4.0-mga-allow-disabled-plugins.patch
Patch1:         0001-CMake-Properly-support-RelWithDebInfo-build-type.patch

ExclusiveArch:  %ix86

BuildRequires:  cmake
BuildRequires:  gettext
BuildRequires:  libaio-devel
BuildRequires:  pcap-devel
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  wxgtku3.0-devel

%description
PCSX2 is an open source Playstation 2 emulator. Its purpose is to mimic
the the PS2 hardware, using a combination of MIPS CPU Interpreters,
Recompilers and a Virtual Machine which manages hardware states and
PS2 system memory.

%files -f %{name}.lang
%doc COPYING.*
%doc %{_docdir}/%{name}/*.pdf
%{_bindir}/PCSX2
%{_bindir}/%{name}_*
%{_datadir}/applications/PCSX2.desktop
%{_datadir}/pixmaps/PCSX2.xpm
%{_datadir}/games/%{name}/cheats_ws.zip
%attr(0666,games,games) %{_datadir}/games/%{name}/GameIndex.dbf
%{_libdir}/games/%{name}/
%{_mandir}/man1/PCSX2.1*

#----------------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}%{?git:-%{date}}

%build
%cmake \
    -DPACKAGE_MODE=TRUE \
    -DXDG_STD=TRUE \
    -DFORCE_INTERNAL_SOUNDTOUCH=FALSE \
    -DBUILD_REPLAY_LOADERS=TRUE \
    -DDISABLE_ADVANCE_SIMD=TRUE \
    -DDISABLE_BUILD_TIME=TRUE \
    -DDISABLE_PCSX2_WRAPPER=TRUE \
    -DEXTRA_PLUGINS=TRUE \
    -DGAMEINDEX_DIR="%{_gamesdatadir}/%{name}" \
    -DPLUGIN_DIR="%{_libdir}/games/%{name}" \
    -DDOC_DIR="%{_docdir}/%{name}" \
    -DSDL2_API=TRUE \
    -DGTK3_API=TRUE
# wxgtk is now built against GTK+3 in mga8

%cmake_build

%install
%cmake_install

%find_lang %{name} --all-name


%changelog
* Wed Jan 26 2022 akien <akien> 1.6.0-2.mga9
+ Revision: 1769846
- Rebuild for new SoundTouch

* Sat May 09 2020 akien <akien> 1.6.0-1.mga8.tainted
+ Revision: 1582394
- Version 1.6.0
+ wally <wally>
- build with new cmake macros

* Wed Sep 18 2019 daviddavid <daviddavid> 1.5.0-0.20190505.2.mga8.tainted
+ Revision: 1443454
- rebuild against wxgtk with gtk3 enabled

* Fri May 10 2019 akien <akien> 1.5.0-0.20190505.1.mga7.tainted
+ Revision: 1396983
- Update to current Git snapshot to fix build with GCC 8
- Build against SDL2
+ daviddavid <daviddavid>
- Mageia 7 Mass Rebuild

* Fri Jun 03 2016 akien <akien> 1.4.0-3.mga6.tainted
+ Revision: 1020193
- Upstream patch to fix build with gcc6 (and apparently 5.4 too for us)
- Rebuild against wxGTK+ 3.0 with GTK+2 API
- Build against wxgtk3.0 (recommended) and thus GTK+3 for us (experimental)

* Sat Jan 16 2016 akien <akien> 1.4.0-2.mga6.tainted
+ Revision: 924755
- Set XDG_STD mode in the build options

* Fri Jan 15 2016 akien <akien> 1.4.0-1.mga6.tainted
+ Revision: 923308
- import pcsx2 based on a ROSA source package

